@@ -1,18 +1,16 @@
-// =================================================================
-//          #     #                 #     #
-//          ##    #   ####   #####  ##    #  ######   #####
-//          # #   #  #    #  #    # # #   #  #          #
-//          #  #  #  #    #  #    # #  #  #  #####      #
-//          #   # #  #    #  #####  #   # #  #          #
-//          #    ##  #    #  #   #  #    ##  #          #
-//          #     #   ####   #    # #     #  ######     #
+// ==========================================================================
+//     _   _ _ ____            ____          _____
+//    | | | (_)  _ \ ___ _ __ / ___|___  _ _|_   _| __ __ _  ___ ___ _ __
+//    | |_| | | |_) / _ \ '__| |   / _ \| '_ \| || '__/ _` |/ __/ _ \ '__|
+//    |  _  | |  __/  __/ |  | |__| (_) | | | | || | | (_| | (_|  __/ |
+//    |_| |_|_|_|   \___|_|   \____\___/|_| |_|_||_|  \__,_|\___\___|_|
 //
-//       ---   The NorNet Testbed for Multi-Homed Systems  ---
-//                       https://www.nntb.no
-// =================================================================
+//       ---  High-Performance Connectivity Tracer (HiPerConTracer)  ---
+//                 https://www.nntb.no/~dreibh/hipercontracer/
+// ==========================================================================
 //
 // High-Performance Connectivity Tracer (HiPerConTracer)
-// Copyright (C) 2015-2022 by Thomas Dreibholz
+// Copyright (C) 2015-2025 by Thomas Dreibholz
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -43,25 +41,25 @@ class DestinationInfo {
                    const uint8_t                   trafficClassValue,
                    const uint32_t                  identifier = 0);
 
-   inline uint32_t identifier() const {
-      return(Identifier);
-   }
    inline const boost::asio::ip::address& address() const {
-      return(Address);
+      return Address;
    }
    inline const uint8_t& trafficClass() const {
-      return(TrafficClass);
+      return TrafficClass;
+   }
+   inline uint32_t identifier() const {
+      return Identifier;
    }
 
-   inline void setIdentifier(const uint8_t identifier) {
-      Identifier = identifier;
-   }
    inline void setAddress(const boost::asio::ip::address& address) {
       Address = address;
    }
    inline void setTrafficClass(const uint8_t trafficClass) {
       TrafficClass = trafficClass;
    }
+   inline void setIdentifier(const uint32_t identifier) {
+      Identifier = identifier;
+   }
 
    private:
    uint32_t                 Identifier;
